@@ -477,7 +477,7 @@ nPoints<-c(nPoints, res_cur$nPoints)
 }
 
 # Now I want to take only the upper levels from identical nPoints
-Index_not_dupl<-(1:length(percentiles))[!duplicated(nPoints)]
+#Index_not_dupl<-(1:length(percentiles))[!duplicated(nPoints)]
 
 #-----------------#
 # and now we want to plot it
@@ -581,7 +581,30 @@ if (is.null(background)) {
 	   save.options$dpi <-600
 	   tmp<-do.call(ggplot2::ggsave, save.options)
 	}
-	return(list(res_buffers=res_buffers, p=p))
+	
+    my.rbind.SpatialPolygons = function(..., makeUniqueIDs = FALSE) {
+       dots = list(...)
+       names(dots) <- NULL
+       stopifnot(sp::identicalCRS(dots))
+       # checkIDSclash(dots)
+       pl = do.call(c, lapply(dots, function(x) methods::slot(x, "polygons")))
+       if (makeUniqueIDs)
+               pl = makeUniqueIDs(pl)
+       sp::SpatialPolygons(pl, proj4string = sp::CRS(sp::proj4string(dots[[1]])))
+	}
+    makeUniqueIDs <- function(lst) {
+	   ids = sapply(lst, function(i) methods::slot(i, "ID"))
+	   if (any(duplicated(ids))) {
+		  ids <- make.unique(as.character(unlist(ids)), sep = "")
+		  for (i in seq(along = ids))
+			lst[[i]]@ID = ids[i]
+	   }
+	   lst
+    }
+	
+	b<-do.call(my.rbind.SpatialPolygons,  c(res_buffers, list(makeUniqueIDs=TRUE))) 
+    SPDF = sp::SpatialPolygonsDataFrame(b, data.frame(percentile = percentiles, row.names=names(b)))
+	return(list(res_buffers=SPDF, p=p, bg=background))
 }
 
 
